@@ -175,13 +175,17 @@ class TgWrap():
         """ Checks for errors """
 
         error = False
+        skip = False
 
         messages = messages.lower()
 
-        if rc.returncode != 0 or 'error' in messages:
+        if rc.returncode != 0 or 'error' in messages.lower():
             error = True
 
-        return error
+        if 'skipping terragrunt module' in messages.lower():
+            skip = True
+
+        return error, skip
 
     def _run_graph_step(self, command, working_dir, module, collect_output_file, dry_run, progress):
         """ Runs a step in the graph """
@@ -225,10 +229,15 @@ class TgWrap():
                 with open(f.name, 'r') as f:
                     messages = f.read()
 
-                error = self._analyze_results(
+                error, skip = self._analyze_results(
                     rc=rc,
                     messages=messages,
                     )
+                
+                # if we have a skipped module, and are collecting output, make sure we end up on a new line
+                if skip and collect_output_file:
+                    self.printer.verbose("Module is skipped")
+                    collect_output_file.write('\n')
 
                 if error:
                     raise Exception(
@@ -559,8 +568,8 @@ class TgWrap():
                     }
 
                     try:
-                        # plan file could be empty if module is skipped
-                        if len(plan_file) > 0:
+                        # plan file could be empty (except for new line) if module is skipped
+                        if len(plan_file) > 1:
                             data = json.loads(plan_file)
 
                             if 'resource_changes' in data and len(data['resource_changes']) > 0:
